@@ -6,9 +6,8 @@ import numpy as np
 from pymatgen.core import Structure
 from structuregraph_helpers.subgraph import get_subgraphs_as_molecules
 
-from .molfromgraph import wrap_molecule
-from ..sbu import Linker, LinkerCollection
-from ..utils import _flatten_list_of_sets
+from moffragmentor.fragmentor.molfromgraph import wrap_molecule
+from moffragmentor.sbu import Linker, LinkerCollection
 
 __all__ = ["create_linker_collection", "identify_linker_binding_indices"]
 
@@ -55,16 +54,16 @@ def _create_linkers_from_node_location_result(  # pylint:disable=too-many-locals
     # First step: remove everything that is node or unbound solvent
     # bound solvent is part of the node by default
     all_node_indices = set()
-    all_persistent_non_metal_bridges = set()
+    # all_persistent_non_metal_bridges = set()
     for node_indices in node_location_result.nodes:
         all_node_indices.update(node_indices)
 
-    for node in node_collection:
-        all_persistent_non_metal_bridges.update(
-            _flatten_list_of_sets(
-                node._persistent_non_metal_bridged  # pylint:disable=protected-access
-            )
-        )
+    # for node in node_collection:
+    #     all_persistent_non_metal_bridges.update(
+    #         _flatten_list_of_sets(
+    #             node._persistent_non_metal_bridged  # pylint:disable=protected-access
+    #         )
+    #     )
 
     not_linker_indices = (
         (
@@ -81,23 +80,13 @@ def _create_linkers_from_node_location_result(  # pylint:disable=too-many-locals
         | set(mof.metal_indices) & all_node_indices
         # some metals might also be in the linker, e.g., in porphyrins
     )
-
-    # potential_linker_indices = set(list(range(len(mof.structure)))) - not_linker_indices
-    # get terminal indices we need to keep in the linker
-
-    # terminal_indices = []
-    # for linker_index in potential_linker_indices:
-    #     for neighbor in mof.get_neighbor_indices(linker_index):
-    #         if mof._is_terminal(neighbor):
-    #             terminal_indices.append(neighbor)
-
     graph_ = mof.structure_graph.__copy__()
     graph_.structure = Structure.from_sites(graph_.structure.sites)
     graph_.remove_nodes(not_linker_indices)
 
     # Second step: extract the connected components
     # return all as molecules
-    mols, graphs, idxs, centers, coordinates = get_subgraphs_as_molecules(
+    _mols, graphs, idxs, _centers, coordinates = get_subgraphs_as_molecules(
         graph_,
         return_unique=False,
         filter_in_cell=False,
@@ -107,29 +96,22 @@ def _create_linkers_from_node_location_result(  # pylint:disable=too-many-locals
 
     # Third: pick those molecules that are closest to the UC
     # ToDo: we should be able to skip this
-    linker_indices, coords = _pick_central_linker_indices(mof, coordinates)
+    linker_indices, _coords = _pick_central_linker_indices(mof, coordinates)
     found_frac_centers = set()
     found_hashes = set()
-    for i, linker_index in enumerate(linker_indices):
+    for linker_index in linker_indices:
         idx = idxs[linker_index]
-        center = centers[linker_index]
-        coords_ = coords[i]
         branching_indices = node_location_result.branching_indices & set(idx)
         mol, mapping = wrap_molecule(idx, mof)
         linker = Linker(
             molecule=mol,
             molecule_graph=graphs[linker_index],
-            center=center,
             graph_branching_indices=branching_indices,
-            closest_branching_index_in_molecule=branching_indices,
             binding_indices=identify_linker_binding_indices(
                 mof,
                 node_location_result.connecting_paths,
                 idx,
             ),
-            coordinates=coords_,
-            original_indices=idx,
-            connecting_paths=[],
             molecule_original_indices_mapping=mapping,
         )
         frac_center = mof.structure.lattice.get_fractional_coords(mol.center_of_mass)
