@@ -1670,31 +1670,28 @@ def get_linker_object():
     linker = Linker(
         mol,
         mg,
-        center=np.array([-502.5498308, -406.76009494, -502.5498308]),
         graph_branching_indices={8, 13, 17},
-        closest_branching_index_in_molecule={1, 37, 46},
         binding_indices=[129, 137, 108, 141, 120, 152],
-        original_indices=[
-            96,
-            129,
-            23,
-            152,
-            60,
-            137,
-            105,
-            0,
-            1,
-            2,
-            108,
-            141,
-            69,
-            37,
-            14,
-            84,
-            120,
-            4,
-        ],
-        connecting_paths=[],
+        molecule_original_indices_mapping={
+            0: [96],
+            1: [129],
+            2: [23],
+            3: [152],
+            4: [60],
+            5: [137],
+            6: [105],
+            7: [0],
+            8: [1],
+            9: [2],
+            10: [108],
+            11: [141],
+            12: [69],
+            13: [37],
+            14: [14],
+            15: [84],
+            16: [120],
+            17: [46],
+        },
     )
     return linker
 
@@ -1707,7 +1704,6 @@ def get_node_object():
         node_indices={32, 1, 132, 134, 72, 137, 74, 139, 108, 110, 113, 115, 27, 30},
         branching_indices={1, 27, 30, 32},
         binding_indices={108, 110, 113, 115, 132, 134, 137, 139},
-        connecting_paths={1, 27, 30, 32, 108, 110, 113, 115, 132, 134, 137, 139},
     )
 
     return node
